==> libksieve-17.12.3.tar.xz: libksieve-17.12.3/src/ksieveui/autocreatescripts/autotests/regexpeditorlineedittest.cpp <==
/*
   Copyright (C) 2017 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "regexpeditorlineedittest.h"
#include "autocreatescripts/sieveconditions/widgets/regexpeditorlineedit.h"
#include <QTest>
#include <QLineEdit>
#include <QHBoxLayout>

RegexpEditorLineEditTest::RegexpEditorLineEditTest(QObject *parent)
    : QObject(parent)
{
}

void RegexpEditorLineEditTest::shouldHaveDefaultValue()
{
    KSieveUi::RegexpEditorLineEdit w;
    QLineEdit *mLineEdit = w.findChild<QLineEdit *>(QStringLiteral("lineedit"));
    QVERIFY(mLineEdit);

    QHBoxLayout *mainLayout = w.findChild<QHBoxLayout *>(QStringLiteral("mainlayout"));
    QVERIFY(mainLayout);
    QCOMPARE(mainLayout->margin(), 0);
}

void RegexpEditorLineEditTest::shouldChangeValue_data()
{
    QTest::addColumn<QString>("input");
    QTest::newRow("empty") << QString();
    QTest::newRow("test1") << QStringLiteral("foo");
}

void RegexpEditorLineEditTest::shouldChangeValue()
{
    QFETCH(QString, input);
    KSieveUi::RegexpEditorLineEdit w;
    w.setCode(input);
    QCOMPARE(w.code(), input);
}

QTEST_MAIN(RegexpEditorLineEditTest)

==> libksieve-19.07.80.tar.xz: libksieve-19.07.80/src/ksieveui/autocreatescripts/autotests/regexpeditorlineedittest.cpp <==
/*
   Copyright (C) 2017-2019 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "regexpeditorlineedittest.h"
#include "kdepimtest_layout.h"
#include "autocreatescripts/sieveconditions/widgets/regexpeditorlineedit.h"
#include <QTest>
#include <QLineEdit>
#include <QHBoxLayout>

RegexpEditorLineEditTest::RegexpEditorLineEditTest(QObject *parent)
    : QObject(parent)
{
}

void RegexpEditorLineEditTest::shouldHaveDefaultValue()
{
    KSieveUi::RegexpEditorLineEdit w;
    QLineEdit *mLineEdit = w.findChild<QLineEdit *>(QStringLiteral("lineedit"));
    QVERIFY(mLineEdit);

    QHBoxLayout *mainLayout = w.findChild<QHBoxLayout *>(QStringLiteral("mainlayout"));
    QVERIFY(mainLayout);
    KdepimTestLayout::checkContentsMargins(0, mainLayout);
}

void RegexpEditorLineEditTest::shouldChangeValue_data()
{
    QTest::addColumn<QString>("input");
    QTest::newRow("empty") << QString();
    QTest::newRow("test1") << QStringLiteral("foo");
}

void RegexpEditorLineEditTest::shouldChangeValue()
{
    QFETCH(QString, input);
    KSieveUi::RegexpEditorLineEdit w;
    w.setCode(input);
    QCOMPARE(w.code(), input);
}

QTEST_MAIN(RegexpEditorLineEditTest)
